{% extends "layouts/base.html" %} {% block title %}Dashboard {% endblock %} {% block body_class %} sidebar-mini {% endblock body_class %} {% block stylesheets %} {% endblock stylesheets %} {% block content %}

# Dashboard

### 150

New Orders

More info

### 53 %

Bounce Rate

More info

### 44

User Registrations

More info

### 65

Unique Visitors

More info

### Sales

### Direct Chat

3
Alexander Pierce 23 Jan 2:00 pm
Is this template really for free? That's unbelievable!
Sarah Bullock 23 Jan 2:05 pm
You better believe it!
Alexander Pierce 23 Jan 5:37 pm
Working with AdminLTE on a great new app! Wanna join?
Sarah Bullock 23 Jan 6:10 pm
I would love to.

- Count Dracula 2/28/2015 How have you been? I was...
- Sarah Doe 2/23/2015 I will be waiting for...
- Nadia Jolie 2/20/2015 I'll call you back at...
- Nora S. Vans 2/10/2015 Where is your new...
- John K. 1/27/2015 Can I take a look at...
- Kenneth M. 1/4/2015 Never mind I found...

### To Do List

- «
- 1
- 2
- 3
- »

- Design a nice theme 2 mins
- Make the theme responsive 4 hours
- Let theme shine like a star 1 day
- Let theme shine like a star 3 days
- Check your messages and notifications 1 week
- Let theme shine like a star 1 month

### Visitors

### Sales Graph

### Calendar

{% endblock content %} {% block javascripts %}
{% endblock javascripts %}